# Start of  Bilko for Windows formula document to radiometrically correct Landsat-5 TM bands 
# 1-3 collected over the Turks and Caicos on 22 November 1990.
#
#	Formula document 1.
#	=================
#
#	Converting DN to at satellite spectral radiance (L) using formulae of the type:
#
#		Lmin + (Lmax/254 - Lmin/255) * @n ;
#
#	Input values
#	==========
#	Lmin: TM1 = -0.116, TM2 = -0.183, TM3 = -0.159
#	Lmax: TM1 = 15.996; TM2 = 31.776; TM3 = 24.394
#


	const Lmin1 = -0.116 ;
	const Lmin2 = -0.183 ;
	const Lmin3 = -0.159 ;

	const Lmax1 = 15.996 ;
	const Lmax2 = 31.776 ;
	const Lmax3 = 24.394 ;

#	Intermediate formulae for L for each TM band:
# 
#	Lmin1 + (Lmax1/254 - Lmin1/255)*@1;
#	Lmin2 + (Lmax2/254 - Lmin2/255)*@2;
#	Lmin3 + (Lmax3/254 - Lmin3/255)*@3;
#
#	Converting at satellite spectral radiance (L) to exoatmospheric reflectance
#
#	Input values
#	==========
#	pi = 3.141593
#	d = 0.975522 JD = 326 for 22/11/90 image.
# 	Sun zenith angle  SZ = 90-39 = 51	 51 = 0.89012 radians
#	ESUN: TM1 = 195.7, TM2 = 182.9, TM3 = 155.7  

	const pi =3.141593 ;
	const dsquared = 0.97552 ;
	const SZ = 0.89012 ;
	const ESUN1 = 195.7 ;
	const ESUN2 = 182.9 ;
	const ESUN3 =  155.7 ; 
#
#	Let at satellite spectral radiance = L  (see intermediate formulae above)
#
#	Converting L to exoatmospheric reflectance (on scale 0-1) with formulae of the type:
#
#		 pi * L * d / (ESUN * cos(SZ))  ;
#

	pi * (Lmin1 + (Lmax1/254 - Lmin1/255)*@1) * dsquared / (ESUN1 * cos(SZ))  ;
	pi * (Lmin2 + (Lmax2/254 - Lmin2/255)*@2) * dsquared / (ESUN2 * cos(SZ))  ;
	pi * (Lmin3 + (Lmax3/254 - Lmin3/255)*@3) * dsquared / (ESUN3 * cos(SZ))  ;

